"use strict";

var _react = _interopRequireDefault(require("react"));
var _reactNative = require("@testing-library/react-native");
var _ = _interopRequireDefault(require("."));
var _types = require("../../../../types");
var _MessageListContext = require("../../../../context/MessageListContext");
var _UuidContext = require("../../../../context/UuidContext");
var _MessageList = require("../../../../entities/MessageList");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
jest.mock('../../../../context/MessageListContext');
jest.mock('../../../../context/UuidContext');
describe('Input', () => {
  beforeAll(() => {
    _MessageListContext.useMessageList.mockReturnValue({
      messageList: new _MessageList.MessageList([])
    });
    _UuidContext.useUuid.mockReturnValue({
      uuid: {
        generate: jest.fn()
      }
    });
  });
  it('renders input field with correct placeholder', () => {
    const {
      getByPlaceholderText
    } = (0, _reactNative.render)( /*#__PURE__*/_react.default.createElement(_.default, null));
    const inputField = getByPlaceholderText('Digite algo ...');
    expect(inputField).toBeTruthy();
  });
  it('calls addMessage when send button is pressed', () => {
    const uuidSpy = jest.spyOn((0, _UuidContext.useUuid)().uuid, 'generate');
    const addMessageSpy = jest.spyOn((0, _MessageListContext.useMessageList)().messageList, 'addMessage');
    const expectedMessage = 'Hello, world!';
    const {
      getByTestId,
      getByPlaceholderText
    } = (0, _reactNative.render)( /*#__PURE__*/_react.default.createElement(_.default, null));
    const sendButton = getByTestId('sendIcon');
    const inputField = getByPlaceholderText('Digite algo ...');
    _reactNative.fireEvent.changeText(inputField, expectedMessage);
    _reactNative.fireEvent.press(sendButton);
    const expectedMsgObject = {
      message: expectedMessage,
      id: undefined,
      from: _types.From.USER,
      type: _types.MessageTypes.TEXT
    };
    expect(uuidSpy).toHaveBeenCalled();
    expect(addMessageSpy).toHaveBeenCalledWith(expectedMsgObject);
    expect(inputField.props.value).toBe('');
  });
  it('does not send empty messages', () => {
    const uuidSpy = jest.spyOn((0, _UuidContext.useUuid)().uuid, 'generate');
    const addMessageSpy = jest.spyOn((0, _MessageListContext.useMessageList)().messageList, 'addMessage');
    const {
      getByTestId
    } = (0, _reactNative.render)( /*#__PURE__*/_react.default.createElement(_.default, null));
    const sendIconElement = getByTestId('sendIcon');
    _reactNative.fireEvent.press(sendIconElement);
    expect(uuidSpy).not.toHaveBeenCalled();
    expect(addMessageSpy).not.toHaveBeenCalled();
  });
  it('handles user input correctly', () => {
    const {
      getByPlaceholderText
    } = (0, _reactNative.render)( /*#__PURE__*/_react.default.createElement(_.default, null));
    const inputElement = getByPlaceholderText('Digite algo ...');
    const expectedMessage = 'test message';
    _reactNative.fireEvent.changeText(inputElement, expectedMessage);
    expect(inputElement.props.value).toBe(expectedMessage);
  });
});
//# sourceMappingURL=index.spec.js.map