"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.MessageHttpSocketGateway = void 0;
var _types = require("../types");
var _MessageList = require("../entities/MessageList");
var _constants = require("../constants");
var _global = require("../global");
class MessageHttpSocketGateway {
  constructor(ws, httpConnection, storage, sessionGateway) {
    this.ws = ws;
    this.httpConnection = httpConnection;
    this.storage = storage;
    this.sessionGateway = sessionGateway;
  }
  async sendStatus(messageId, status) {
    const sessionId = await this.sessionGateway.getCurrent();
    const payload = {
      sessionId,
      botId: _global.Global.botId,
      status,
      messageId
    };
    await this.httpConnection.post('/webchat/status', payload);
  }
  async getMessages() {
    const messages = await this.storage.retrieve('messages');
    return new _MessageList.MessageList(JSON.parse(messages) || []);
  }
  async sendMessage(msg) {
    const messagesData = JSON.parse((await this.storage.retrieve('messages')) || '[]');
    messagesData.push(msg);
    await this.storage.store('messages', JSON.stringify(messagesData));
    const sessionId = await this.sessionGateway.getCurrent();
    if (!sessionId) {
      await this.sessionGateway.subscribe('');
    } else {
      this.httpConnection.post('/webchat/message', {
        botId: _global.Global.botId,
        message: msg.message,
        isMedia: msg.type !== _types.MessageTypes.TEXT,
        ext: msg.ext,
        sessionId: sessionId,
        botChannel: _constants.channel,
        isPreview: false,
        socketId: _global.Global.socketId
      });
    }
    return new _MessageList.MessageList(messagesData);
  }
  async storeMessage(msg) {
    const messages = JSON.parse((await this.storage.retrieve('messages')) || '[]');
    messages.push(msg);
    await this.storage.store('messages', JSON.stringify(messages));
    return new _MessageList.MessageList(messages);
  }
  async clearMessages() {
    const messageList = [];
    await this.storage.store('messages', JSON.stringify(messageList));
    return new _MessageList.MessageList(messageList);
  }
  onMessage(callback) {
    this.ws.onMessage(callback);
  }
}
exports.MessageHttpSocketGateway = MessageHttpSocketGateway;
//# sourceMappingURL=MessageHttpSocketGateway.js.map