"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.MessageListProvider = void 0;
var _react = _interopRequireWildcard(require("react"));
var _types = require("../types");
var _UuidContext = require("../context/UuidContext");
var _MessageListContext = _interopRequireDefault(require("../context/MessageListContext"));
var _MessageList = require("../entities/MessageList");
var _Observer = require("../entities/Observer");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
const MessageListProvider = _ref => {
  let {
    messageGateway,
    notificationGateway,
    children
  } = _ref;
  const {
    uuid
  } = (0, _UuidContext.useUuid)();
  const [initialMessages, setInitialMessages] = (0, _react.useState)(new _MessageList.MessageList([]));
  (0, _react.useEffect)(() => {
    const fetchInitialMessages = async () => {
      const messages = await messageGateway.getMessages();
      messageGateway.onMessage(data => {
        messages.addMessage({
          ...data,
          id: data.id || uuid.generate(),
          from: _types.From.BOT
        });
        if (data.type !== _types.MessageTypes.TYPING) {
          notificationGateway.postLocal(data.message);
        }
      });
      messages.register(new _Observer.Observer('clearMessages', async () => {
        setInitialMessages(await messageGateway.clearMessages());
      }));
      messages.register(new _Observer.Observer('addMessage', async data => {
        if (data.type !== _types.MessageTypes.TYPING) {
          if (data.from === _types.From.USER) {
            setInitialMessages(await messageGateway.sendMessage(data));
          } else {
            await messageGateway.sendStatus(data.id, 'delivered');
            setInitialMessages(await messageGateway.storeMessage(data));
          }
        }
      }));
      setInitialMessages(messages);
    };
    fetchInitialMessages();
  }, []);
  return /*#__PURE__*/_react.default.createElement(_MessageListContext.default, {
    initialMessageList: initialMessages
  }, children);
};
exports.MessageListProvider = MessageListProvider;
//# sourceMappingURL=MessageListProvider.js.map