import React from 'react';
import { TouchableOpacity, Image } from 'react-native';
import DocumentPicker from 'react-native-document-picker';
import { toBase64 } from '../../../../../../utils';
import { MessageTypes, From } from '../../../../../../types';
import { styles } from './styles';
import attachIcon from '../../../../../../assets/attach_icon.png';
import { useUuid } from '../../../../../../context/UuidContext';
import { useMessageList } from '../../../../../../context/MessageListContext';
export const getMessageType = type => {
  switch (type) {
    case 'application':
    case 'msword':
    case 'text':
      return MessageTypes.DOCUMENT;
    case 'video':
      return MessageTypes.VIDEO;
    case 'image':
      return MessageTypes.IMAGE;
    default:
      return MessageTypes.IMAGE;
  }
};
const FilePicker = () => {
  const {
    uuid
  } = useUuid();
  const {
    messageList
  } = useMessageList();
  const handleSubmitMessage = msg => {
    messageList.addMessage(msg);
  };
  const handleDocumentSelection = async () => {
    try {
      const response = await DocumentPicker.pick({
        presentationStyle: 'fullScreen',
        allowMultiSelection: true
      });
      if (response) {
        await Promise.all(response.map(async file => {
          var _file$type;
          const [type, ext] = file === null || file === void 0 ? void 0 : (_file$type = file.type) === null || _file$type === void 0 ? void 0 : _file$type.split('/');
          const messageType = getMessageType(type);
          const base64String = await toBase64(file === null || file === void 0 ? void 0 : file.uri);
          const msg = {
            id: uuid.generate(),
            ext,
            from: From.USER,
            isMedia: true,
            type: messageType,
            message: `data:${file === null || file === void 0 ? void 0 : file.type};base64,${base64String}`,
            localFileUri: file === null || file === void 0 ? void 0 : file.uri
          };
          if ([MessageTypes.DOCUMENT, MessageTypes.VIDEO].includes(messageType)) {
            msg.document = {
              fileUrl: file === null || file === void 0 ? void 0 : file.uri,
              size: file === null || file === void 0 ? void 0 : file.size,
              title: file === null || file === void 0 ? void 0 : file.name
            };
          }
          return handleSubmitMessage(msg);
        }));
      }
    } catch (err) {
      if (DocumentPicker.isCancel(err)) return;
      throw err;
    }
  };
  return /*#__PURE__*/React.createElement(TouchableOpacity, {
    testID: "filePicker",
    onPress: handleDocumentSelection
  }, /*#__PURE__*/React.createElement(Image, {
    source: attachIcon,
    style: styles.attachIcon
  }));
};
export default FilePicker;
//# sourceMappingURL=index.js.map